(ns blog.server
  (:require ["express" :as express]
            ["express-handlebars" :refer [engine]]
            [blog.db :as db]
            [blog.env :as env]))

(def app (express))
(def port (env/get-port))
(def client (db/create-client))

(defn setup-engine
  "Sets the engine to handlebars and simple set up."
  []

  ; For using .hbs as the file extension instead of .handlebars
  (. app
     engine ".hbs" (engine (-> {:extname ".hbs"
                                :defaultLayout "main"}
                               (cljs.core/clj->js))))

  (. app
     set "view engine" ".hbs")

  (. app
     set "views" "./views"))

(defn set-routes
  "Sets the routes for server."
  []
  (. app get "/"
     (fn [req res]
       (. res send "Hello world"))))

(defn start
  "Starts server."
  []
  (setup-engine)
  (set-routes)

  (db/connect-client client)

  (. app listen port
     (fn []
       (println "Listen on " port))))

